@@ -4,12 +4,13 @@
 #
 
 CC=gcc
-CCFLAG=-O -fPIC
-LDFLAG=-O -s
+CCFLAG=-O2 -fPIC
+LDFLAG=-O2 -s
 AR=ar rs
 RANLIB=touch
-XINCLUDE=-I/usr/X11R6/include
+XINCLUDE=--I/usr/X11R6/include
 SYSLIB=-L/usr/X11R6/lib -lX11 -lm
+JPEG=
 
 # where the library should be installed
 
@@ -33,14 +34,18 @@ FORMLIB=libforms.a
 FORMHEADER=forms.h
 
 # make shared lib: $(MKSHLIB)
-SHARED_LIB=libforms.so.0.88
-SHARED_SO=libforms.so.0.88
+SHARED_LIB=libforms.so.0.89
+SHARED_SO=libforms.so.0.89
 SHARED_NAME=libforms.so
 
 #
 # this is how the shared library is made
 #
 MKSHLIB=ld -shared -soname $(SHARED_SO) -o $(SHARED_LIB)\
-     `ls *.o|grep -v gl.o` ulib/*.o ../xpm-3.4g/lib/libXpm.a -lc
+     `ls *.o|grep -v glcanvas.o` ulib/*.o ../xpm-3.4k/lib/libXpm.a $(JPEG) -lc
 
 LN=ln -fs
+
+#suffix for executables
+EXE=
+
